@@ -4,19 +4,21 @@ import collections
 import functools
 import datetime
 import locale
-from visidata import option, options, TypedWrapper, vd, VisiData
+from visidata import options, TypedWrapper, vd, VisiData
 
 #__all__ = ['anytype', 'vdtype', ]
 
-option('disp_currency_fmt', '%.02f', 'default fmtstr to format for currency values', replay=True)
-option('disp_float_fmt', '{:.02f}', 'default fmtstr to format for float values', replay=True)
-option('disp_int_fmt', '{:.0f}', 'default fmtstr to format for int values', replay=True)
-option('disp_date_fmt','%Y-%m-%d', 'default fmtstr to strftime for date values', replay=True)
+vd.option('disp_currency_fmt', '%.02f', 'default fmtstr to format for currency values', replay=True)
+vd.option('disp_float_fmt', '{:.02f}', 'default fmtstr to format for float values', replay=True)
+vd.option('disp_int_fmt', '{:.0f}', 'default fmtstr to format for int values', replay=True)
+vd.option('disp_date_fmt','%Y-%m-%d', 'default fmtstr to strftime for date values', replay=True)
 
 try:
-    import dateutil.parser
+    from dateutil.parser import parse as date_parse
 except ImportError:
-    pass
+    def date_parse(r=''):
+        vd.warning('install python-dateutil for date type')
+        return r
 
 # VisiDataType .typetype are e.g. int, float, str, and used internally in these ways:
 #
@@ -163,7 +165,7 @@ class date(datetime.datetime):
         if isinstance(s, int) or isinstance(s, float):
             r = datetime.datetime.fromtimestamp(s)
         elif isinstance(s, str):
-            r = dateutil.parser.parse(s)
+            r = date_parse(s)
         elif isinstance(s, (datetime.datetime, datetime.date)):
             r = s
         else:
@@ -174,9 +176,37 @@ class date(datetime.datetime):
         tzinfo = getattr(r, 'tzinfo', None)
         return super().__new__(cls, *t[:6], microsecond=ms, tzinfo=tzinfo, **kwargs)
 
+    def __lt__(self, b):
+        if isinstance(b, datetime.datetime): return datetime.datetime.__lt__(self, b)
+        elif isinstance(b, datetime.date):   return not self.date().__eq__(b) and self.date().__lt__(b)
+        return NotImplemented
+
+    def __gt__(self, b):
+        if isinstance(b, datetime.datetime): return datetime.datetime.__gt__(self, b)
+        elif isinstance(b, datetime.date):   return not self.date().__eq__(b) and self.date().__gt__(b)
+        return NotImplemented
+
+    def __le__(self, b):
+        if isinstance(b, datetime.datetime): return datetime.datetime.__le__(self, b)
+        elif isinstance(b, datetime.date):   return self.date().__le__(b)
+        return NotImplemented
+
+    def __ge__(self, b):
+        if isinstance(b, datetime.datetime): return datetime.datetime.__le__(self, b)
+        elif isinstance(b, datetime.date):   return self.date().__ge__(b)
+        return NotImplemented
+
+    def __eq__(self, b):
+        if isinstance(b, datetime.datetime): return datetime.datetime.__eq__(self, b)
+        elif isinstance(b, datetime.date): return self.date().__eq__(b)
+        return NotImplemented
+
     def __str__(self):
         return self.strftime(options.disp_date_fmt)
 
+    def __hash__(self):
+        return super().__hash__()
+
     def __float__(self):
         return self.timestamp()
 
